@@ -14,12 +14,15 @@ class MjpegParser(object):
     self.format = 'jpeg'
     self.input = urllib2.urlopen(url)
     self.length = 0
+    # mimic the same data
+    self.data = ''
 
   def serve(self):
     while True:
       regex = re.compile("\d+")
       content_length = 0
       content = ''
+      self.data = ''
       while content_length == 0:
         if 'Content-Length'.lower() in content.lower():
           length = regex.findall(content)
@@ -28,6 +31,7 @@ class MjpegParser(object):
             self.length = content_length
         content = self.input.readline()
         data = self.input.read(content_length)
+        self.data += content
 
       if self.pil:
           output = StringIO.StringIO()
